#!/usr/bin/env python
# vim: set ts=4 sts=4 sw=4 textwidth=92:

"""
Holds the OldRAR class.

This module works with old-style rar sets.

It will detect sets like the following:
X.par2
X.vol0+1.par2
...

Y.rar
Y.r00
Y.r01
...

Where the PAR2 files protect all of the rar files. Note that Y can be the same
as X, but is not required to be.
"""

__author__    = "Ira W. Snyder (devel@irasnyder.com)"
__copyright__ = "Copyright (c) 2006,2007 Ira W. Snyder (devel@irasnyder.com)"
__license__   = "GNU GPL v2 (or, at your option, any later version)"

#    OldRAR.py -- detect and work with old-style rar sets
#
#    Copyright (C) 2006,2007  Ira W. Snyder (devel@irasnyder.com)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import os
import PAR2Set.Base
import rsutil.common


def detector (name_files, prot_files):
	"""Detect OldRAR sets"""

	return rsutil.common.has_a_match ('^.*\.r00$', prot_files)


class OldRAR (PAR2Set.Base.Base):

	"""Class for working with old-style rar sets"""

	def __repr__ (self):
		return 'OLDRAR'

	def find_extraction_heads (self):
		"""Find the heads of extraction for an old-style rar set"""

		return rsutil.common.find_matches ('^.*\.rar$', self.all_files)

	def extraction_function (self, file, todir):
		"""Extract a single rar file to the given directory.

		   file -- the file to extract
		   todir -- the directory to extract the file to"""

		assert os.path.isfile (file)
		assert os.path.isdir (todir)

		RAR_CMD = rsutil.common.config_get_value ('commands', 'unrar')

		cmd = '%s \"%s\"' % (RAR_CMD, file)
		ret = rsutil.common.run_command (cmd, todir)

		# Check error code
		if ret != 0:
			return -rsutil.common.EEXTRACT

		return rsutil.common.SUCCESS

